@@ -4,13 +4,14 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Util 'camelize';
 use Mojo::Loader 'load_class';
 use Carp;
+use Data::Dump qw/dump/;
 
 use constant BASE => {
     files      => [],
     references => {}
 };
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub register {
     my ($self, $app, $conf) = @_;
@@ -30,6 +31,8 @@ sub register {
     $self->_find_files($path_routes);
 
     $self->_load_routes($app, $moniker, $namespace, $inverse);
+    
+    $self->_clean_base;
 }
 
 sub _find_files {
@@ -59,6 +62,8 @@ sub _load_routes {
     my ($self, $app, $moniker, $namespace, $inverse) = @_;
 
     my $base = $moniker . '::' . $namespace;
+    
+    my $routes = $app->routes;
 
     for my $file (@{BASE->{files}}) {
         $file =~ s/\//::/g;
@@ -68,21 +73,26 @@ sub _load_routes {
         if ($class && $class->isa('MojoX::Route')) {            
             my $ref = $class->new(app => $app);
 
-            $self->_any($app, $ref, $file, $base, $inverse)   if $class->can('any');
-            $self->_under($app, $ref, $file, $base, $inverse) if $class->can('under');
-            $self->_route($app, $ref, $file, $base, $inverse) if $class->can('route');
+            $self->_any($routes, $ref, $file, $base, $inverse)   if $class->can('any');
+            $self->_under($routes, $ref, $file, $base, $inverse) if $class->can('under');
+            $self->_route($routes, $ref, $file, $base, $inverse) if $class->can('route');
         }
     }
 }
 
+sub _clean_base {
+    @{BASE->{files}} = ();
+    %{BASE->{references}} = ();
+}
+
 sub _any {
-    my ($self, $app, $ref, $file, $base, $inverse) = @_;
+    my ($self, $routes, $ref, $file, $base, $inverse) = @_;
 
     my ($name, $ref_name) = $self->_ref_name($file, $base);
     
     my @params;
     push(@params, BASE->{references}->{$ref_name}) if $self->_valid_reference($ref_name);
-    push(@params, $app->routes);    
+    push(@params, $routes);    
 
     my $any = $ref->any($inverse ? reverse(@params) : @params);
 
@@ -90,13 +100,13 @@ sub _any {
 }
 
 sub _under {
-    my ($self, $app, $ref, $file, $base, $inverse) = @_;
+    my ($self, $routes, $ref, $file, $base, $inverse) = @_;
 
     my ($name, $ref_name) = $self->_ref_name($file, $base);
     
     my @params;
     push(@params, BASE->{references}->{$ref_name}) if $self->_valid_reference($ref_name);
-    push(@params, $app->routes);    
+    push(@params, $routes);    
 
     my $under = $ref->under($inverse ? reverse(@params) : @params);
 
@@ -104,14 +114,14 @@ sub _under {
 }
 
 sub _route {
-    my ($self, $app, $ref, $file, $base, $inverse) = @_;
+    my ($self, $routes, $ref, $file, $base, $inverse) = @_;
 
     my ($name, $ref_name) = $self->_ref_name($file, $base);
     
     my @params;
     push(@params, BASE->{references}->{$name})     if $self->_valid_reference($name);
     push(@params, BASE->{references}->{$ref_name}) if $self->_valid_reference($ref_name);
-    push(@params, $app->routes);
+    push(@params, $routes);
 
     $ref->route($inverse ? reverse(@params) : @params);
 }
