@@ -2,11 +2,15 @@ package Lite::Route::Bar::Qux::B;
 use Mojo::Base 'MojoX::Route';
 
 sub route {
-    my ($self, $r) = @_;
+    my ($self, $qux, $r) = @_;
 
-    $r->get('/b' => sub {
+    $qux->get('/b' => sub {
         shift->render(text => 'Bar::Qux::B');
     });
+    
+    $r->get('/b' => sub {
+        shift->render(text => 'B');
+    });
 }
 
 1;
